#include "ClocXPlugin.h"
#include "ConfigDialog.h"
#include <stdio.h>
/*
This is an example plugin for ClocX.
Unused EXPORT functions leave commented, they will not be called
*/

#define OUTPUTFILE "HelloWorld.dll"

HINSTANCE hPluginInstance;   /* contains instance handle of this DLL */
char appPath[MAX_PATH];   /* for storing full path of our plugin */
int SkinWidth;
int SkinHeight;
POINT AMPMCenter;
int AMPMFontSize;

BOOL APIENTRY DllMain( HINSTANCE hinstDLL, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
/* this code is executed every time DLL is loaded */
{
	hPluginInstance = hinstDLL;
	/* you can get full path-name of this DLL file eg. to store configs here */
	GetModuleFileName(GetModuleHandle(OUTPUTFILE),appPath,MAX_PATH);
    
	 switch (ul_reason_for_call)
	{
		case DLL_PROCESS_ATTACH:
		case DLL_THREAD_ATTACH:
		case DLL_THREAD_DETACH:
		case DLL_PROCESS_DETACH:
			break;
    }
    return TRUE;
}


EXPORT int OnInit (InitData *idat)
/* OnInit is called when module is loaded 
(but not when it is loaded only for configuration */
{
	return 0;  /* 0 = OK,  1 = Error,  -1 = OK but unload this plugin */
}


/* OnConfig is called when user clicks Configure in Plugin Options */
EXPORT void OnConfig (HWND ParentDlg)
{
	DialogBox(hPluginInstance, MAKEINTRESOURCE(IDD_CONFIGDIALOG), ParentDlg, (DLGPROC)ConfigProc);
}

/* OnSkinLoaded is called after ClocX load a skin */
EXPORT void OnSkinLoaded (SkinLoadedData *sld)
{
	/* copy some important values from sld */
	SkinWidth = sld->Width;
	SkinHeight = sld->Height;
	AMPMCenter = sld->AMPMCenter;
	AMPMFontSize = sld->AMPMFontSize;
}

/* OnTick should be called every second */
/*
EXPORT void OnTick (SYSTEMTIME *systime, FILETIME *ftime)
{

}
*/

/*OnDrawBegin is called when clock drawing began */
/* Things drawed here will apear under hands, AM/PM/Date texts etc. */
EXPORT void OnDrawBegin (HDC hdc)
{
	HFONT hMyFont;
	LOGFONT lfont = {-AMPMFontSize,0,0,0,FW_NORMAL,
		FALSE,FALSE,FALSE,DEFAULT_CHARSET,OUT_DEFAULT_PRECIS,CLIP_DEFAULT_PRECIS,
		DEFAULT_QUALITY,FIXED_PITCH | FF_ROMAN, "Arial"};
	hMyFont = CreateFontIndirect(&lfont);
	if (hMyFont) {
		RECT rect1;
		SetBkMode(hdc,TRANSPARENT);
		SetTextColor(hdc,RGB(255,0,0));
/*		rect1.left=AMPMCenter.x-(SkinWidth>>1);  //draw below AM/PM
		rect1.top=AMPMCenter.y-(SkinHeight>>1)+32;
		rect1.right=AMPMCenter.x + (SkinWidth>>1);
		rect1.bottom=AMPMCenter.y + (SkinHeight>>1);*/
		rect1.left = 0;
		rect1.top = 50;
		rect1.right = SkinWidth;
		rect1.bottom = SkinHeight;
		HFONT hOldFont = (HFONT) SelectObject(hdc,hMyFont);
		DrawText(hdc,"Hello World",11,&rect1,DT_CENTER | DT_NOCLIP |DT_SINGLELINE|DT_VCENTER);
		SelectObject(hdc, hOldFont);
		DeleteObject(hMyFont);
	}
}

/* OnDrawedImage is called when clock is drawn do hdc, before drawing to screen */
/* Objects drawed here will apear above other objects as hands, texts etc */
/*
EXPORT void OnDrawedImage (HDC hdc)
{

}
*/

/* OnDestroy is called on ClocX exit */
/*
EXPORT void OnDestroy ()
{


}
*/